@@ -29,19 +29,24 @@
  */
 
 #include <config.h>
+
 #include "nautilus-tree-view-drag-dest.h"
 
-#include <eel/eel-gtk-macros.h>
-#include <gtk/gtk.h>
 #include "nautilus-file-dnd.h"
 #include "nautilus-file-changes-queue.h"
 #include "nautilus-icon-dnd.h"
 #include "nautilus-link.h"
 #include "nautilus-marshal.h"
-#include "nautilus-debug-log.h"
+
+#include <eel/eel-gtk-macros.h>
+#include <gtk/gtk.h>
+
 #include <stdio.h>
 #include <string.h>
 
+#define DEBUG_FLAG NAUTILUS_DEBUG_LIST_VIEW
+#include "nautilus-debug.h"
+
 #define AUTO_SCROLL_MARGIN 20
 
 #define HOVER_EXPAND_TIMEOUT 1
@@ -88,7 +93,6 @@ static const GtkTargetEntry drag_types [] = {
 	/* prefer "_NETSCAPE_URL" over "text/uri-list" to satisfy web browsers. */
 	{ NAUTILUS_ICON_DND_NETSCAPE_URL_TYPE, 0, NAUTILUS_ICON_DND_NETSCAPE_URL },
 	{ NAUTILUS_ICON_DND_URI_LIST_TYPE, 0, NAUTILUS_ICON_DND_URI_LIST },
-	{ NAUTILUS_ICON_DND_KEYWORD_TYPE, 0, NAUTILUS_ICON_DND_KEYWORD },
 	{ NAUTILUS_ICON_DND_XDNDDIRECTSAVE_TYPE, 0, NAUTILUS_ICON_DND_XDNDDIRECTSAVE }, /* XDS Protocol Type */
 	{ NAUTILUS_ICON_DND_RAW_TYPE, 0, NAUTILUS_ICON_DND_RAW }
 };
@@ -105,7 +109,7 @@ gtk_tree_view_vertical_autoscroll (GtkTreeView *tree_view)
 	float value;
 	
 	window = gtk_tree_view_get_bin_window (tree_view);
-	vadjustment = gtk_tree_view_get_vadjustment (tree_view);
+	vadjustment = gtk_scrollable_get_vadjustment (GTK_SCROLLABLE (tree_view));
 	
 	gdk_window_get_pointer (window, NULL, &y, NULL);
 	
@@ -173,29 +177,24 @@ remove_expand_timeout (NautilusTreeViewDragDest *dest)
 }
 
 static gboolean
-highlight_expose (GtkWidget *widget,
-		  GdkEventExpose *event,
-		  gpointer data)
+highlight_draw (GtkWidget *widget,
+		cairo_t   *cr,
+                gpointer data)
 {
 	GdkWindow *bin_window;
 	int width;
 	int height;
 
-	if (gtk_widget_is_drawable (widget)) {
-		bin_window = 
-			gtk_tree_view_get_bin_window (GTK_TREE_VIEW (widget));
-		
-		gdk_drawable_get_size (bin_window, &width, &height);
-		
-		gtk_paint_focus (gtk_widget_get_style (widget),
-				 bin_window,
-				 gtk_widget_get_state (widget),
-				 NULL,
-				 widget,
-				 "treeview-drop-indicator",
-				 0, 0, width, height);
-	}
-	
+        /* FIXMEchpe: is bin window right here??? */
+        bin_window = gtk_tree_view_get_bin_window (GTK_TREE_VIEW (widget));
+
+        width = gdk_window_get_width (bin_window);
+        height = gdk_window_get_height (bin_window);
+
+        gtk_render_focus (gtk_widget_get_style_context (widget),
+			  cr,
+			  0, 0, width, height);
+
 	return FALSE;
 }
 
@@ -212,8 +211,8 @@ set_widget_highlight (NautilusTreeViewDragDest *dest, gboolean highlight)
 	if (highlight && !dest->details->highlight_id) {
 		dest->details->highlight_id = 
 			g_signal_connect_object (dest->details->tree_view,
-						 "expose_event",
-						 G_CALLBACK (highlight_expose),
+						 "draw",
+						 G_CALLBACK (highlight_draw),
 						 dest, 0);
 		gtk_widget_queue_draw (GTK_WIDGET (dest->details->tree_view));
 	}
@@ -437,13 +436,6 @@ get_drop_action (NautilusTreeViewDragDest *dest,
 	case NAUTILUS_ICON_DND_XDNDDIRECTSAVE:
 		return GDK_ACTION_COPY;
 
-	case NAUTILUS_ICON_DND_KEYWORD:
-
-		if (!path) {
-			return 0;
-		}
-
-		return GDK_ACTION_COPY;
 	}
 
 	return 0;
@@ -751,32 +743,6 @@ receive_dropped_netscape_url (NautilusTreeViewDragDest *dest,
 	g_free (drop_target);
 }
 
-static void
-receive_dropped_keyword (NautilusTreeViewDragDest *dest,
-			 GdkDragContext *context,
-			 int x, int y)
-{
-	char *drop_target_uri;
-	NautilusFile *drop_target_file;
-
-	if (!dest->details->drag_data) {
-		return;
-	}
-
-	drop_target_uri = get_drop_target_uri_at_pos (dest, x, y);
-	g_assert (drop_target_uri != NULL);
-
-	drop_target_file = nautilus_file_get_by_uri (drop_target_uri);
-
-	if (drop_target_file != NULL) {
-		nautilus_drag_file_receive_dropped_keyword (drop_target_file,
-							    (char *) gtk_selection_data_get_data (dest->details->drag_data));
-		nautilus_file_unref (drop_target_file);
-	}
-
-	g_free (drop_target_uri);
-}
-
 static gboolean
 receive_xds (NautilusTreeViewDragDest *dest,
 	     GtkWidget *widget,
@@ -870,10 +836,6 @@ drag_data_received_callback (GtkWidget *widget,
 			receive_dropped_raw (dest, tmp, length, context, x, y);
 			success = TRUE;
 			break;
-		case NAUTILUS_ICON_DND_KEYWORD:
-			receive_dropped_keyword (dest, context, x, y);
-			success = TRUE;
-			break;
 		case NAUTILUS_ICON_DND_XDNDDIRECTSAVE:
 			finished = receive_xds (dest, widget, time, context, x, y);
 			success = TRUE;
@@ -914,8 +876,7 @@ get_direct_save_filename (GdkDragContext *context)
 	/* Verify that the file name provided by the source is valid */
 	if (*prop_text == '\0' ||
 	    strchr ((const gchar *) prop_text, G_DIR_SEPARATOR) != NULL) {
-		nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
-				    "Invalid filename provided by XDS drag site");
+		DEBUG ("Invalid filename provided by XDS drag site");
 		g_free (prop_text);
 		return NULL;
 	}
@@ -949,7 +910,7 @@ set_direct_save_uri (NautilusTreeViewDragDest *dest,
 			g_object_unref (child);
 
 			/* Change the property */
-			gdk_property_change (GDK_DRAWABLE (gdk_drag_context_get_source_window (context)),
+			gdk_property_change (gdk_drag_context_get_source_window (context),
 					     gdk_atom_intern (NAUTILUS_ICON_DND_XDNDDIRECTSAVE_TYPE, FALSE),
 					     gdk_atom_intern ("text/plain", FALSE), 8,
 					     GDK_PROP_MODE_REPLACE, (const guchar *) uri,
@@ -957,12 +918,10 @@ set_direct_save_uri (NautilusTreeViewDragDest *dest,
 
 			dest->details->direct_save_uri = uri;
 		} else {
-			nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
-					    "Invalid filename provided by XDS drag site");
+			DEBUG ("Invalid filename provided by XDS drag site");
 		}
 	} else {
-		nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
-				    "Could not retrieve XDS drop destination");
+		DEBUG ("Could not retrieve XDS drop destination");
 	}
 
 	return uri != NULL;
