@@ -33,19 +33,15 @@
 #include "file-manager/fm-desktop-icon-view.h"
 #include "file-manager/fm-icon-view.h"
 #include "file-manager/fm-list-view.h"
-#include "file-manager/fm-tree-view.h"
 #if ENABLE_EMPTY_VIEW
 #include "file-manager/fm-empty-view.h"
 #endif /* ENABLE_EMPTY_VIEW */
 
 #include "nautilus-application-smclient.h"
 #include "nautilus-desktop-window.h"
-#include "nautilus-history-sidebar.h"
 #include "nautilus-image-properties-page.h"
 #include "nautilus-navigation-window.h"
 #include "nautilus-navigation-window-slot.h"
-#include "nautilus-notes-viewer.h"
-#include "nautilus-places-sidebar.h"
 #include "nautilus-self-check-functions.h"
 #include "nautilus-spatial-window.h"
 #include "nautilus-window-bookmarks.h"
@@ -53,8 +49,7 @@
 #include "nautilus-window-private.h"
 #include "nautilus-window-slot.h"
 
-#include <libnautilus-private/nautilus-autorun.h>
-#include <libnautilus-private/nautilus-debug-log.h>
+#include <libnautilus-private/nautilus-dbus-manager.h>
 #include <libnautilus-private/nautilus-desktop-link-monitor.h>
 #include <libnautilus-private/nautilus-directory-private.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
@@ -66,6 +61,9 @@
 #include <libnautilus-private/nautilus-undo-manager.h>
 #include <libnautilus-extension/nautilus-menu-provider.h>
 
+#define DEBUG_FLAG NAUTILUS_DEBUG_APPLICATION
+#include <libnautilus-private/nautilus-debug.h>
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -104,14 +102,6 @@ static void     mount_removed_callback            (GVolumeMonitor            *mo
 static void     mount_added_callback              (GVolumeMonitor            *monitor,
 						   GMount                    *mount,
 						   NautilusApplication       *application);
-static void     volume_added_callback              (GVolumeMonitor           *monitor,
-						    GVolume                  *volume,
-						    NautilusApplication      *application);
-static void     drive_connected_callback           (GVolumeMonitor           *monitor,
-						    GDrive                   *drive,
-						    NautilusApplication      *application);
-static void     drive_listen_for_eject_button      (GDrive *drive, 
-						    NautilusApplication *application);
 
 G_DEFINE_TYPE (NautilusApplication, nautilus_application, GTK_TYPE_APPLICATION);
 
@@ -121,46 +111,6 @@ nautilus_application_get_spatial_window_list (void)
 	return nautilus_application_spatial_window_list;
 }
 
-static void
-startup_volume_mount_cb (GObject *source_object,
-			 GAsyncResult *res,
-			 gpointer user_data)
-{
-	g_volume_mount_finish (G_VOLUME (source_object), res, NULL);
-}
-
-static void
-automount_all_volumes (NautilusApplication *application)
-{
-	GList *volumes, *l;
-	GMount *mount;
-	GVolume *volume;
-
-	if (g_settings_get_boolean (nautilus_media_preferences, NAUTILUS_PREFERENCES_MEDIA_AUTOMOUNT)) {
-		/* automount all mountable volumes at start-up */
-		volumes = g_volume_monitor_get_volumes (application->volume_monitor);
-		for (l = volumes; l != NULL; l = l->next) {
-			volume = l->data;
-			
-			if (!g_volume_should_automount (volume) ||
-			    !g_volume_can_mount (volume)) {
-				continue;
-			}
-			
-			mount = g_volume_get_mount (volume);
-			if (mount != NULL) {
-				g_object_unref (mount);
-				continue;
-			}
-
-			/* pass NULL as GMountOperation to avoid user interaction */
-			g_volume_mount (volume, 0, NULL, NULL, startup_volume_mount_cb, NULL);
-		}
-		g_list_free_full (volumes, g_object_unref);
-	}
-	
-}
-
 static gboolean
 check_required_directories (NautilusApplication *application)
 {
@@ -260,17 +210,6 @@ menu_provider_init_callback (void)
         nautilus_module_extension_list_free (providers);
 }
 
-static gboolean
-automount_all_volumes_idle_cb (gpointer data)
-{
-	NautilusApplication *application = NAUTILUS_APPLICATION (data);
-
-	automount_all_volumes (application);
-
-	application->automount_idle_id = 0;
-	return FALSE;
-}
-
 static void
 mark_desktop_files_trusted (void)
 {
@@ -339,6 +278,7 @@ ck_session_proxy_signal_cb (GDBusProxy *proxy,
 
 	if (g_strcmp0 (signal_name, "ActiveChanged") == 0) {
 		g_variant_get (parameters, "(b)", &application->session_is_active);
+		DEBUG ("ConsoleKit session is active %d", application->session_is_active);
 	}
 }
 
@@ -362,6 +302,7 @@ ck_call_is_active_cb (GDBusProxy   *proxy,
 	}
 
 	g_variant_get (variant, "(b)", &application->session_is_active);
+	DEBUG ("ConsoleKit session is active %d", application->session_is_active);
 
 	g_variant_unref (variant);
 }
@@ -423,6 +364,8 @@ ck_get_current_session_cb (GDBusConnection *connection,
 
 	g_variant_get (variant, "(&o)", &session_path);
 
+	DEBUG ("Found ConsoleKit session at path %s", session_path);
+
 	g_dbus_proxy_new_for_bus (G_BUS_TYPE_SYSTEM,
 				  G_DBUS_PROXY_FLAGS_NONE,
 				  NULL,
@@ -525,8 +468,6 @@ static void
 finish_startup (NautilusApplication *application,
 		gboolean no_desktop)
 {
-	GList *drives;
-
 	do_upgrades_once (application, no_desktop);
 	
 	/* initialize nautilus modules */
@@ -554,21 +495,6 @@ finish_startup (NautilusApplication *application,
 				 G_CALLBACK (mount_removed_callback), application, 0);
 	g_signal_connect_object (application->volume_monitor, "mount_added",
 				 G_CALLBACK (mount_added_callback), application, 0);
-	g_signal_connect_object (application->volume_monitor, "volume_added",
-				 G_CALLBACK (volume_added_callback), application, 0);
-	g_signal_connect_object (application->volume_monitor, "drive_connected",
-				 G_CALLBACK (drive_connected_callback), application, 0);
-
-	/* listen for eject button presses */
-	drives = g_volume_monitor_get_connected_drives (application->volume_monitor);
-	g_list_foreach (drives, (GFunc) drive_listen_for_eject_button, application);
-	g_list_foreach (drives, (GFunc) g_object_unref, NULL);
-	g_list_free (drives);
-
-	application->automount_idle_id = 
-		g_idle_add_full (G_PRIORITY_LOW,
-				 automount_all_volumes_idle_cb,
-				 application, NULL);
 }
 
 static void
@@ -579,7 +505,7 @@ open_window (NautilusApplication *application,
 {
 	GFile *location;
 	NautilusWindow *window;
-	gboolean existing;
+	gboolean existing, open_in_browser;
 
 	if (uri == NULL) {
 		location = g_file_new_for_path (g_get_home_dir ());
@@ -587,10 +513,14 @@ open_window (NautilusApplication *application,
 		location = g_file_new_for_uri (uri);
 	}
 
+	open_in_browser = browser_window ||
+		g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER);
+
+	DEBUG ("Opening new window at uri %s, browser %d", uri, open_in_browser);
+
 	existing = FALSE;
 
-	if (browser_window ||
-	    g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER)) {
+	if (open_in_browser) {
 		window = nautilus_application_create_navigation_window (application,
 									startup_id,
 									screen);
@@ -753,6 +683,9 @@ nautilus_application_create_desktop_windows (NautilusApplication *application)
 					NAUTILUS_PREFERENCES_EXIT_WITH_LAST_WINDOW);
 
 	for (i = 0; i < screens; i++) {
+
+		DEBUG ("Creating a desktop window for screen %d", i);
+		
 		selection_widget = get_desktop_manager_selection (display, i);
 		if (selection_widget != NULL) {
 			window = nautilus_desktop_window_new (application,
@@ -1008,8 +941,8 @@ create_window (NautilusApplication *application,
 static void
 spatial_window_destroyed_callback (void *user_data, GObject *window)
 {
-	nautilus_application_spatial_window_list = g_list_remove (nautilus_application_spatial_window_list, window);
-		
+	nautilus_application_spatial_window_list =
+		g_list_remove (nautilus_application_spatial_window_list, window);
 }
 
 NautilusWindow *
@@ -1021,7 +954,6 @@ nautilus_application_get_spatial_window (NautilusApplication *application,
 					 gboolean            *existing)
 {
 	NautilusWindow *window;
-	gchar *uri;
 
 	g_return_val_if_fail (NAUTILUS_IS_APPLICATION (application), NULL);
 
@@ -1033,6 +965,8 @@ nautilus_application_get_spatial_window (NautilusApplication *application,
 			*existing = TRUE;
 		}
 
+		DEBUG ("returning existing spatial window");
+
 		return window;
 	}
 
@@ -1068,12 +1002,8 @@ nautilus_application_get_spatial_window (NautilusApplication *application,
 	g_object_weak_ref (G_OBJECT (window), 
 			   spatial_window_destroyed_callback, NULL);
 
-	uri = g_file_get_uri (location);
-	nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
-			    "present NEW spatial window=%p: %s",
-			    window, uri);
-	g_free (uri);
-	
+	DEBUG ("Creating new spatial window");
+
 	return window;
 }
 
@@ -1132,10 +1062,8 @@ nautilus_application_create_navigation_window (NautilusApplication *application,
 	}
 	g_free (geometry_string);
 
-	nautilus_debug_log (FALSE, NAUTILUS_DEBUG_LOG_DOMAIN_USER,
-			    "create new navigation window=%p",
-			    window);
-
+	DEBUG ("Creating a new navigation window");
+	
 	return window;
 }
 
@@ -1163,105 +1091,6 @@ window_can_be_closed (NautilusWindow *window)
 	return FALSE;
 }
 
-static void
-volume_added_callback (GVolumeMonitor *monitor,
-		       GVolume *volume,
-		       NautilusApplication *application)
-{
-	if (g_settings_get_boolean (nautilus_media_preferences, NAUTILUS_PREFERENCES_MEDIA_AUTOMOUNT) &&
-	    g_volume_should_automount (volume) &&
-	    g_volume_can_mount (volume)) {
-		nautilus_file_operations_mount_volume (NULL, volume, TRUE);
-	} else {
-		/* Allow nautilus_autorun() to run. When the mount is later
-		 * added programmatically (i.e. for a blank CD),
-		 * nautilus_autorun() will be called by mount_added_callback(). */
-		nautilus_allow_autorun_for_volume (volume);
-		nautilus_allow_autorun_for_volume_finish (volume);
-	}
-}
-
-static void
-drive_eject_cb (GObject *source_object,
-		GAsyncResult *res,
-		gpointer user_data)
-{
-	GError *error;
-	char *primary;
-	char *name;
-	error = NULL;
-	if (!g_drive_eject_with_operation_finish (G_DRIVE (source_object), res, &error)) {
-		if (error->code != G_IO_ERROR_FAILED_HANDLED) {
-			name = g_drive_get_name (G_DRIVE (source_object));
-			primary = g_strdup_printf (_("Unable to eject %s"), name);
-			g_free (name);
-			eel_show_error_dialog (primary,
-					       error->message,
-				       NULL);
-			g_free (primary);
-		}
-		g_error_free (error);
-	}
-}
-
-static void
-drive_eject_button_pressed (GDrive *drive,
-			    NautilusApplication *application)
-{
-	GMountOperation *mount_op;
-
-	mount_op = gtk_mount_operation_new (NULL);
-	g_drive_eject_with_operation (drive, 0, mount_op, NULL, drive_eject_cb, NULL);
-	g_object_unref (mount_op);
-}
-
-static void
-drive_listen_for_eject_button (GDrive *drive, NautilusApplication *application)
-{
-	g_signal_connect (drive,
-			  "eject-button",
-			  G_CALLBACK (drive_eject_button_pressed),
-			  application);
-}
-
-static void
-drive_connected_callback (GVolumeMonitor *monitor,
-			  GDrive *drive,
-			  NautilusApplication *application)
-{
-	drive_listen_for_eject_button (drive, application);
-}
-
-static void
-autorun_show_window (GMount *mount, gpointer user_data)
-{
-	GFile *location;
-	NautilusApplication *application = user_data;
-	NautilusWindow *window;
-	gboolean existing;
-
-	location = g_mount_get_root (mount);
-	existing = FALSE;
-
-	/* There should probably be an easier way to do this */
-	if (g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER)) {
-		window = nautilus_application_create_navigation_window (application, 
-									NULL, 
-									gdk_screen_get_default ());
-	} else {
-		window = nautilus_application_get_spatial_window (application,
-								  NULL,
-								  NULL,
-								  location,
-								  gdk_screen_get_default (),
-								  NULL);
-	}
-
-	nautilus_window_go_to (window, location);
-
-	g_object_unref (location);
-}
-
 static void
 mount_added_callback (GVolumeMonitor *monitor,
 		      GMount *mount,
@@ -1269,20 +1098,24 @@ mount_added_callback (GVolumeMonitor *monitor,
 {
 	NautilusDirectory *directory;
 	GFile *root;
+	gchar *uri;
 
 	if (!application->session_is_active) {
 		return;
 	}
 		
 	root = g_mount_get_root (mount);
+	uri = g_file_get_uri (root);
+
+	DEBUG ("Added mount at uri %s", uri);
+	g_free (uri);
+	
 	directory = nautilus_directory_get_existing (root);
 	g_object_unref (root);
 	if (directory != NULL) {
 		nautilus_directory_force_reload (directory);
 		nautilus_directory_unref (directory);
 	}
-
-	nautilus_autorun (mount, autorun_show_window, application);
 }
 
 static NautilusWindowSlot *
@@ -1330,6 +1163,7 @@ mount_removed_callback (GVolumeMonitor *monitor,
 	NautilusWindowSlot *force_no_close_slot;
 	GFile *root, *computer;
 	gboolean unclosed_slot;
+	gchar *uri;
 
 	close_list = NULL;
 	force_no_close_slot = NULL;
@@ -1339,6 +1173,11 @@ mount_removed_callback (GVolumeMonitor *monitor,
 	window_list = gtk_application_get_windows (GTK_APPLICATION (application));
 
 	root = g_mount_get_root (mount);
+	uri = g_file_get_uri (root);
+
+	DEBUG ("Removed mount at uri %s", uri);
+	g_free (uri);
+
 	/* Construct a list of windows to be closed. Do not add the non-closable windows to the list. */
 	for (node = window_list; node != NULL; node = node->next) {
 		window = NAUTILUS_WINDOW (node->data);
@@ -1353,7 +1192,8 @@ mount_removed_callback (GVolumeMonitor *monitor,
 				for (l = pane->slots; l != NULL; l = l->next) {
 					slot = l->data;
 					location = slot->location;
-					if (g_file_has_prefix (location, root) ||
+					if (location == NULL ||
+					    g_file_has_prefix (location, root) ||
 					    g_file_equal (location, root)) {
 						close_list = g_list_prepend (close_list, slot);
 
@@ -1438,19 +1278,34 @@ nautilus_application_finalize (GObject *object)
 		application->volume_monitor = NULL;
 	}
 
-	if (application->automount_idle_id != 0) {
-		g_source_remove (application->automount_idle_id);
-		application->automount_idle_id = 0;
-	}
-
 	if (application->proxy != NULL) {
 		g_object_unref (application->proxy);
 		application->proxy = NULL;
 	}
 
+	nautilus_dbus_manager_stop ();
+
         G_OBJECT_CLASS (nautilus_application_parent_class)->finalize (object);
 }
 
+void
+nautilus_application_quit (NautilusApplication *self)
+{
+	GApplication *app = G_APPLICATION (self);
+	gboolean exit_with_last_window;
+
+	exit_with_last_window =
+		g_settings_get_boolean (nautilus_preferences,
+					NAUTILUS_PREFERENCES_EXIT_WITH_LAST_WINDOW);
+
+	nautilus_application_close_desktop ();
+	g_application_release (app);
+
+	if (!exit_with_last_window) {
+		g_application_release (app);
+	}
+}
+
 static gint
 nautilus_application_command_line (GApplication *app,
 				   GApplicationCommandLine *command_line)
@@ -1578,27 +1433,20 @@ nautilus_application_command_line (GApplication *app,
 		no_desktop = FALSE;
 	}
 
+	DEBUG ("Parsing command line, no_default_window %d browser %d, quit %d, "
+	       "self checks %d, no_desktop %d",
+	       no_default_window, browser_window, kill_shell, perform_self_check, no_desktop);
+
 	exit_with_last_window =
 		g_settings_get_boolean (nautilus_preferences,
 					NAUTILUS_PREFERENCES_EXIT_WITH_LAST_WINDOW);
 
 	if (kill_shell) {
-		nautilus_application_close_desktop ();
-		g_application_release (app);
-
-		if (!exit_with_last_window) {
-			g_application_release (app);
-		}
+		nautilus_application_quit (self);
 	} else {
 		if (!self->initialized) {
 			char *accel_map_filename;
 
-			nautilus_application_smclient_init (self);
-
-			if (egg_sm_client_is_resumed (self->smclient)) {
-				no_default_window = TRUE;
-			}
-
 			if (!no_desktop &&
 			    !g_settings_get_boolean (gnome_background_preferences,
 						     NAUTILUS_PREFERENCES_SHOW_DESKTOP)) {
@@ -1630,8 +1478,8 @@ nautilus_application_command_line (GApplication *app,
 			g_signal_connect (gtk_accel_map_get (), "changed",
 					  G_CALLBACK (queue_accel_map_save_callback), NULL);
 
-			/* Load session info if availible */
-			nautilus_application_smclient_load (self);
+			/* Initialize SMClient and load session info if availible */
+			nautilus_application_smclient_load (self, &no_default_window);
 
 			self->initialized = TRUE;
 		}
@@ -1688,11 +1536,13 @@ nautilus_application_startup (GApplication *app)
 	 */
 	G_APPLICATION_CLASS (nautilus_application_parent_class)->startup (app);
 
+	DEBUG ("Application startup");
+
 	/* create an undo manager */
 	self->undo_manager = nautilus_undo_manager_new ();
 
 	/* initialize the session manager client */
-	egg_sm_client_set_mode (EGG_SM_CLIENT_MODE_DISABLED);
+	nautilus_application_smclient_startup (self);
 
 	/* Initialize preferences. This is needed to create the
 	 * global GSettings objects.
@@ -1708,23 +1558,21 @@ nautilus_application_startup (GApplication *app)
 	fm_empty_view_register ();
 #endif /* ENABLE_EMPTY_VIEW */
 
-	/* register sidebars */
-	nautilus_places_sidebar_register ();
-	fm_tree_view_register ();
-	nautilus_history_sidebar_register ();
-	nautilus_notes_viewer_register (); /* also property page */
-
 	/* register property pages */
 	nautilus_image_properties_page_register ();
 
 	/* initialize search path for custom icons */
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
 					   NAUTILUS_DATADIR G_DIR_SEPARATOR_S "icons");
+
+	nautilus_dbus_manager_start ();
 }
 
 static void
 nautilus_application_quit_mainloop (GApplication *app)
 {
+	DEBUG ("Quitting mainloop");
+
 	nautilus_icon_info_clear_caches ();
  	nautilus_application_save_accel_map (NULL);
 
@@ -1751,7 +1599,7 @@ NautilusApplication *
 nautilus_application_dup_singleton (void)
 {
 	return g_object_new (NAUTILUS_TYPE_APPLICATION,
-			     "application-id", "org.gnome.Nautilus",
+			     "application-id", "org.gnome.NautilusApplication",
 			     "flags", G_APPLICATION_HANDLES_COMMAND_LINE,
 			     NULL);
 }
