@@ -33,7 +33,6 @@
 #include "nautilus-application.h"
 #include "nautilus-connect-server-dialog.h"
 #include "nautilus-file-management-properties.h"
-#include "nautilus-property-browser.h"
 #include "nautilus-window-manage-views.h"
 #include "nautilus-window-bookmarks.h"
 #include "nautilus-window-private.h"
@@ -43,7 +42,6 @@
 #include <gio/gio.h>
 #include <glib/gi18n.h>
 #include <eel/eel-gtk-extensions.h>
-#include <eel/eel-preferences.h>
 #include <libnautilus-extension/nautilus-menu-provider.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
@@ -239,16 +237,9 @@ action_connect_to_server_callback (GtkAction *action,
 				   gpointer user_data)
 {
 	NautilusWindow *window = NAUTILUS_WINDOW (user_data);
-	NautilusWindowSlot *slot;
 	GtkWidget *dialog;
-	GFile *location;
 
-	slot = nautilus_window_get_active_slot (window);
-	location = nautilus_window_slot_get_location (slot);
-	dialog = nautilus_connect_server_dialog_new (window, location);
-	if (location) {
-		g_object_unref (location);
-	}
+	dialog = nautilus_connect_server_dialog_new (window);
 
 	gtk_widget_show (dialog);
 }
@@ -424,7 +415,7 @@ show_hidden_files_preference_callback (gpointer callback_data)
 		/* update button */
 		g_signal_handlers_block_by_func (action, action_show_hidden_files_callback, window);
 		gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
-					      eel_preferences_get_boolean (NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES));
+					      g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES));
 		g_signal_handlers_unblock_by_func (action, action_show_hidden_files_callback, window);
 
 		/* inform views */
@@ -433,15 +424,6 @@ show_hidden_files_preference_callback (gpointer callback_data)
 	}
 }
 
-static void
-preferences_respond_callback (GtkDialog *dialog,
-			      gint response_id)
-{
-	if (response_id == GTK_RESPONSE_CLOSE) {
-		gtk_widget_destroy (GTK_WIDGET (dialog));
-	}
-}
-
 static void
 action_preferences_callback (GtkAction *action, 
 			     gpointer user_data)
@@ -450,18 +432,7 @@ action_preferences_callback (GtkAction *action,
 
 	window = GTK_WINDOW (user_data);
 
-	nautilus_file_management_properties_dialog_show (G_CALLBACK (preferences_respond_callback), window);
-}
-
-static void
-action_backgrounds_and_emblems_callback (GtkAction *action, 
-					 gpointer user_data)
-{
-	GtkWindow *window;
-
-	window = GTK_WINDOW (user_data);
-
-	nautilus_property_browser_show (gtk_window_get_screen (window));
+	nautilus_file_management_properties_dialog_show (window);
 }
 
 static void
@@ -472,8 +443,11 @@ action_about_nautilus_callback (GtkAction *action,
 		"Alexander Larsson",
 		"Ali Abdin",
 		"Anders Carlsson",
+		"Andrew Walton",
 		"Andy Hertzfeld",
 		"Arlo Rose",
+		"Christian Neumair",
+		"Cosimo Cecchi",
 		"Darin Adler",
 		"David Camp",
 		"Eli Goldberg",
@@ -506,7 +480,7 @@ action_about_nautilus_callback (GtkAction *action,
 	};
 	const gchar *documenters[] = {
 		"GNOME Documentation Team",
-		"Sun Microsystem",
+		"Sun Microsystems",
 		NULL
 	};
 	const gchar *license[] = {
@@ -533,7 +507,7 @@ action_about_nautilus_callback (GtkAction *action,
 			       "comments", _("Nautilus lets you organize "
 					     "files and folders, both on "
 					     "your computer and online."),
-			       "copyright", _("Copyright \xC2\xA9 1999-2009 "
+			       "copyright", _("Copyright \xC2\xA9 1999-2010 "
 					      "The Nautilus authors"),
 			       "license", license_trans,
 			       "wrap-license", TRUE,
@@ -789,10 +763,6 @@ static const GtkActionEntry main_entries[] = {
   /* label, accelerator */       N_("_Close"), "<control>W",
   /* tooltip */                  N_("Close this folder"),
                                  G_CALLBACK (action_close_window_slot_callback) },
-                               { "Backgrounds and Emblems", NULL,
-                                 N_("_Backgrounds and Emblems..."),               
-                                 NULL, N_("Display patterns, colors, and emblems that can be used to customize appearance"),
-                                 G_CALLBACK (action_backgrounds_and_emblems_callback) },
                                { "Preferences", GTK_STOCK_PREFERENCES,
                                  N_("Prefere_nces"),               
                                  NULL, N_("Edit Nautilus preferences"),
@@ -913,13 +883,13 @@ nautilus_window_initialize_menus (NautilusWindow *window)
 	action = gtk_action_group_get_action (action_group, NAUTILUS_ACTION_SHOW_HIDDEN_FILES);
 	g_signal_handlers_block_by_func (action, action_show_hidden_files_callback, window);
 	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
-				      eel_preferences_get_boolean (NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES));
+				      g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES));
 	g_signal_handlers_unblock_by_func (action, action_show_hidden_files_callback, window);
 
 
-	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES,
-						  show_hidden_files_preference_callback,
-						  window, G_OBJECT (window));
+	g_signal_connect_swapped (nautilus_preferences, "changed::" NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES,
+				  G_CALLBACK(show_hidden_files_preference_callback),
+				  window);
 
 	window->details->ui_manager = gtk_ui_manager_new ();
 	ui_manager = window->details->ui_manager;
@@ -938,7 +908,6 @@ nautilus_window_initialize_menus (NautilusWindow *window)
 	gtk_ui_manager_add_ui_from_string (ui_manager, ui, -1, NULL);
 
 	nautilus_window_initialize_trash_icon_monitor (window);
-	nautilus_window_initialize_bookmarks_menu (window);
 }
 
 static GList *
